-- Generically look at all indexes - and persist this data so that you can analyze over time

USE [PerformanceDW]
go

-- drop the table... 
-- drop table [persisted:dm_db_index_usage_stats]

-- Create the permanent table
SELECT getdate() AS RunTime 
	, DB_NAME(i.database_id) as DatabaseName
	, OBJECT_NAME(i.object_id, i.database_id) as ObjectName
	, *
	, 1 AS [Rank]
INTO [persisted:dm_db_index_usage_stats]
FROM sys.dm_db_index_usage_stats AS i
WHERE 1=2 
go

INSERT [persisted:dm_db_index_usage_stats]
SELECT getdate()  
	, DB_NAME(i.database_id) 
	, OBJECT_NAME(i.object_id, i.database_id) 
	, *
FROM 
	(SELECT *, 
	DENSE_RANK() OVER (PARTITION BY database_id ORDER BY database_id ASC) AS [Rank]
	FROM sys.dm_db_index_usage_stats) AS i
WHERE object_id > 100 AND DB_NAME(i.database_id) NOT IN ('master', 'model', 'msdb', 'tempdb')
go

SELECT *
FROM [persisted:dm_db_index_usage_stats]
WHERE object_id > 100
ORDER BY DatabaseName ASC
go

-- Verify the indexes NOT used for a particular database
-- Remember, these are the indexes NOT used since you started gathering "usage stats"
-- If you have NOT gathered stats over a true "business cycle" then you may NOT
-- have accurate stats (for example for month end processing) and therefore you 
-- might actually drop an index that's very critical for a report or other.

USE credit
go

SELECT object_name(si.object_id) AS 'TableName'
	, si.name AS 'IndexName'
	, N'DROP INDEX ' 
		+ QUOTENAME(object_name(si.object_id), N']') 
		+ N'.' 
		+ QUOTENAME(si.name, N']') AS 'Drop Index Statement'
FROM sys.indexes AS si 
WHERE si.index_id 
	NOT IN (SELECT pStats.index_id 
            FROM [PerformanceDW].dbo.[persisted:dm_db_index_usage_stats] AS pStats 
            WHERE pStats.object_id = si.object_id AND 
                  si.index_id = pStats.index_id AND 
                  database_id = db_id()) 
AND si.object_id > 100
ORDER BY object_name(si.object_id)
go

-----------------------------------------------------------------------
-- Here's a copy of the query if you just want to run it one time:
-----------------------------------------------------------------------
SELECT getdate() AS RunTime 
	, DB_NAME(i.database_id) as DatabaseName
	, OBJECT_NAME(i.object_id, i.database_id) as ObjectName
	, *
FROM 
	(SELECT *, 
	DENSE_RANK() OVER (PARTITION BY database_id ORDER BY database_id ASC) AS rnk
	FROM sys.dm_db_index_usage_stats) AS i
WHERE object_id > 100
go